# Changelog

- This file provides a full account of all changes to `dbt-tests-adapter`
- The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html),
and is generated by [Changie](https://github.com/miniscruff/changie)
- Changes are listed under the (pre-)release in which they first appear
- Subsequent releases include changes from previous releases
- "Breaking changes" listed under a version may require action from end users or external maintainers when upgrading to that version
- Do not edit this file directly. This file is auto-generated using [changie](https://github.com/miniscruff/changie)
- For details on how to document a change, see the [contributing guide](/CONTRIBUTING.md#changelog-entry)

## dbt-tests-adapter 1.15.0 - May 02, 2025

### Features

- Add base test case for sample mode ([#878](https://github.com/dbt-labs/dbt-adapters/issues/878))
- Add tests for `empty` and `sample` modes against python models ([#906](https://github.com/dbt-labs/dbt-adapters/issues/906))

### Fixes

- `datetime.datetime.utcnow()` is deprecated as of Python 3.12 ([#980](https://github.com/dbt-labs/dbt-adapters/issues/980))



## dbt-tests-adapter 1.11.0 - February 07, 2025
